==> qtjambi-multimedia-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiMultimedia/QSoundEffect_shell.h <==
#ifndef QSOUNDEFFECT_SHELL_H
#define QSOUNDEFFECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qsoundeffect.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtJambi/RegistryAPI>


class QSoundEffect_shell : public QSoundEffect, public QtJambiShellInterface
{
public:
    QSoundEffect_shell(const QAudioDevice& audioDevice0, QObject* parent1 = nullptr);
    QSoundEffect_shell(QObject* parent0 = nullptr);
    ~QSoundEffect_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QSoundEffect_mshell;
    friend class QSoundEffect_oshell;
};


class QSoundEffect_mshell : public QSoundEffect_shell
{
public:
    using QSoundEffect_shell::QSoundEffect_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QSoundEffect_oshell : public QSoundEffect_mshell
{
public:
    using QSoundEffect_mshell::QSoundEffect_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSoundEffect_access : public QSoundEffect
{
};

#endif // QSOUNDEFFECT_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.7.0.jar: sources/QtJambiMultimedia/QSoundEffect_shell.h <==
#ifndef QSOUNDEFFECT_SHELL_H
#define QSOUNDEFFECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qsoundeffect.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtJambi/RegistryAPI>


class QSoundEffect_shell : public QSoundEffect, public QtJambiShellInterface
{
public:
    QSoundEffect_shell(const QAudioDevice& audioDevice0, QObject* parent1 = nullptr);
    QSoundEffect_shell(QObject* parent0 = nullptr);
    ~QSoundEffect_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSoundEffect_access : public QSoundEffect
{
};

#endif // QSOUNDEFFECT_SHELL_H
